==> polymer-sound-patcher-0.14.2+1.21.9-sources.jar: eu/pb4/polymer/soundpatcher/mixin/block/EntityMixin.java <==
package eu.pb4.polymer.soundpatcher.mixin.block;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import eu.pb4.polymer.soundpatcher.api.SoundPatcher;
import eu.pb4.polymer.soundpatcher.impl.CoreBridge;
import eu.pb4.polymer.soundpatcher.impl.SoundRemapperImpl;
import net.minecraft.class_1297;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import net.minecraft.class_3414;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import xyz.nucleoid.packettweaker.PacketContext;

@Mixin(class_1297.class)
public class EntityMixin {
    @WrapOperation(method = "playStepSound", at = @At(value = "INVOKE", target = "Lnet/minecraft/entity/Entity;playSound(Lnet/minecraft/sound/SoundEvent;FF)V"))
    private void playSoundCorrectlyForBlocks(class_1297 instance, class_3414 sound, float volume, float pitch, Operation<Void> original, @Local(argsOnly = true) class_2680 state) {
        if (instance instanceof class_3222 player
                && SoundRemapperImpl.SOUND_EXCEPTION_IGNORER.contains(CoreBridge.getClientSideSoundGroup(state, PacketContext.create(player)).method_10594().comp_3319())) {
            try (var t = SoundRemapperImpl.ignorePlaySoundExclusion()) {
                original.call(instance, sound, volume, pitch);
            }
        } else {
            original.call(instance, sound, volume, pitch);
        }
    }
}

==> polymer-sound-patcher-0.15.0+1.21.11-sources.jar: eu/pb4/polymer/soundpatcher/mixin/block/EntityMixin.java <==
package eu.pb4.polymer.soundpatcher.mixin.block;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import eu.pb4.polymer.soundpatcher.api.SoundPatcher;
import eu.pb4.polymer.soundpatcher.impl.CoreBridge;
import eu.pb4.polymer.soundpatcher.impl.SoundRemapperImpl;
import net.minecraft.class_1297;
import net.minecraft.class_2680;
import net.minecraft.class_3222;
import net.minecraft.class_3414;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import xyz.nucleoid.packettweaker.PacketContext;

@Mixin(class_1297.class)
public class EntityMixin {
    @WrapOperation(method = "playStepSound", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/Entity;playSound(Lnet/minecraft/sounds/SoundEvent;FF)V"))
    private void playSoundCorrectlyForBlocks(class_1297 instance, class_3414 sound, float volume, float pitch, Operation<Void> original, @Local(argsOnly = true) class_2680 state) {
        if (instance instanceof class_3222 player
                && SoundRemapperImpl.SOUND_EXCEPTION_IGNORER.contains(CoreBridge.getClientSideSoundGroup(state, PacketContext.create(player)).method_10594().comp_3319())) {
            try (var t = SoundRemapperImpl.ignorePlaySoundExclusion()) {
                original.call(instance, sound, volume, pitch);
            }
        } else {
            original.call(instance, sound, volume, pitch);
        }
    }
}
